import { IConsentContract } from "../interfaces/IConsentContract";
import { ContractOverrides, WrappedTransactionResponse } from "../interfaces/objects";
import { ConsentRoles, Tag } from "../interfaces/objects/index.js";
import { ICryptoUtils } from "@snickerdoodlelabs/common-utils";
import { ConsentContractError, EVMAccountAddress, EVMContractAddress, IpfsCID, TokenUri, Signature, TokenId, RequestForData, BlockNumber, DomainName, BaseURI, HexString, HexString32, InvalidParametersError, ConsentToken, BigNumberString } from "@snickerdoodlelabs/objects";
import { ethers, EventFilter, Event } from "ethers";
import { ResultAsync } from "neverthrow";
export declare class ConsentContract implements IConsentContract {
    protected providerOrSigner: ethers.providers.Provider | ethers.providers.JsonRpcSigner | ethers.Wallet;
    protected contractAddress: EVMContractAddress;
    protected cryptoUtils: ICryptoUtils;
    protected contract: ethers.Contract;
    constructor(providerOrSigner: ethers.providers.Provider | ethers.providers.JsonRpcSigner | ethers.Wallet, contractAddress: EVMContractAddress, cryptoUtils: ICryptoUtils);
    getContractAddress(): EVMContractAddress;
    optIn(tokenId: TokenId, agreementFlags: HexString32, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    encodeOptIn(tokenId: TokenId, agreementFlags: HexString32): HexString;
    restrictedOptIn(tokenId: TokenId, agreementFlags: HexString32, signature: Signature, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    encodeRestrictedOptIn(tokenId: TokenId, signature: Signature, agreementFlags: HexString32): HexString;
    anonymousRestrictedOptIn(tokenId: TokenId, agreementFlags: HexString32, signature: Signature, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    encodeAnonymousRestrictedOptIn(tokenId: TokenId, signature: Signature, agreementFlags: HexString32): HexString;
    optOut(tokenId: TokenId, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    encodeOptOut(tokenId: TokenId): HexString;
    agreementFlags(tokenId: TokenId): ResultAsync<HexString32, ConsentContractError>;
    getMaxCapacity(): ResultAsync<number, ConsentContractError>;
    updateMaxCapacity(maxCapacity: number, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    requestForData(ipfsCID: IpfsCID, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    getConsentOwner(): ResultAsync<EVMAccountAddress, ConsentContractError>;
    getDefaultAdminRoleMembers(): ResultAsync<EVMAccountAddress[], ConsentContractError>;
    getSignerRoleMembers(): ResultAsync<EVMAccountAddress[], ConsentContractError>;
    getPauserRoleMembers(): ResultAsync<EVMAccountAddress[], ConsentContractError>;
    getRequesterRoleMembers(): ResultAsync<EVMAccountAddress[], ConsentContractError>;
    balanceOf(address: EVMAccountAddress): ResultAsync<number, ConsentContractError>;
    ownerOf(tokenId: TokenId): ResultAsync<EVMAccountAddress, ConsentContractError>;
    tokenURI(tokenId: TokenId): ResultAsync<TokenUri | null, ConsentContractError>;
    queryFilter(eventFilter: EventFilter, fromBlock?: BlockNumber, toBlock?: BlockNumber): ResultAsync<Event[], ConsentContractError>;
    getConsentToken(tokenId: TokenId): ResultAsync<ConsentToken, ConsentContractError>;
    addDomain(domain: string, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    removeDomain(domain: string, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    getDomains(): ResultAsync<DomainName[], ConsentContractError>;
    getRequestForDataListByRequesterAddress(requesterAddress: EVMAccountAddress, fromBlock?: BlockNumber, toBlock?: BlockNumber): ResultAsync<RequestForData[], ConsentContractError>;
    getLatestTokenIdByOptInAddress(optInAddress: EVMAccountAddress): ResultAsync<TokenId | null, ConsentContractError>;
    disableOpenOptIn(overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    enableOpenOptIn(overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    baseURI(): ResultAsync<BaseURI, ConsentContractError>;
    setBaseURI(baseUri: BaseURI, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    hasRole(role: keyof typeof ConsentRoles, address: EVMAccountAddress): ResultAsync<boolean, ConsentContractError>;
    grantRole(role: keyof typeof ConsentRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    revokeRole(role: keyof typeof ConsentRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    renounceRole(role: keyof typeof ConsentRoles, address: EVMAccountAddress, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    getQueryHorizon(): ResultAsync<BlockNumber, ConsentContractError>;
    setQueryHorizon(blockNumber: BlockNumber, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    totalSupply(): ResultAsync<number, ConsentContractError>;
    openOptInDisabled(): ResultAsync<boolean, ConsentContractError>;
    getMaxTags(): ResultAsync<number, ConsentContractError>;
    getNumberOfStakedTags(): ResultAsync<number, ConsentContractError>;
    getTagArray(): ResultAsync<Tag[], ConsentContractError>;
    newGlobalTag(tag: string, newStakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    newLocalTagUpstream(tag: string, newStakeAmount: BigNumberString, existingStakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    newLocalTagDownstream(tag: string, existingStakeAmount: BigNumberString, newStakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    replaceExpiredListing(tag: string, stakeAmount: BigNumberString, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    removeListing(tag: string, overrides?: ContractOverrides): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    filters: {
        Transfer: (fromAddress: EVMAccountAddress | null, toAddress: EVMAccountAddress | null) => EventFilter;
        RequestForData: (ownerAddress: EVMAccountAddress) => EventFilter;
    };
    getSignature(values: (string | EVMAccountAddress | ethers.BigNumber | HexString | EVMContractAddress)[]): ResultAsync<Signature, InvalidParametersError>;
    protected writeToContract(functionName: string, functionParams: any[]): ResultAsync<WrappedTransactionResponse, ConsentContractError>;
    protected toWrappedTransactionResponse(transactionResponse: ethers.providers.TransactionResponse, functionName: string, functionParams: any[]): WrappedTransactionResponse;
}
//# sourceMappingURL=ConsentContract.d.ts.map